==> chromium-54.0.2840.61.tar.xz: chromium-54.0.2840.61/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/NearTopTapSuppression.java <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.contextualsearch;

/**
 * Heuristic for Tap suppression near the top of the content view area.
 * Handles logging of results seen and the condition state.
 */
public class NearTopTapSuppression extends ContextualSearchHeuristic {
    private final int mExperiementThresholdDps;
    private final boolean mIsConditionSatisfied;
    private final int mYDp;

    /**
     * Constructs a Tap suppression heuristic that handles a Tap after a recent scroll.
     * This logs activation data that includes whether it activated for a threshold specified
     * by an experiment. This also logs Results-seen data to profile when results are seen relative
     * to a recent scroll.
     * @param selectionController The {@link ContextualSearchSelectionController}.
     */
    NearTopTapSuppression(ContextualSearchSelectionController selectionController, int y) {
        mExperiementThresholdDps = ContextualSearchFieldTrial.getScreenTopSuppressionDps();
        mYDp = (int) (y * selectionController.getPxToDp());
        mIsConditionSatisfied = mYDp < ContextualSearchFieldTrial.getScreenTopSuppressionDps();
    }

    @Override
    protected boolean isConditionSatisfied() {
        return mIsConditionSatisfied;
    }

    @Override
    protected void logConditionState() {
        if (mExperiementThresholdDps > 0) {
            ContextualSearchUma.logScreenTopTapSuppression(mIsConditionSatisfied);
        }
    }

    @Override
    protected void logResultsSeen(boolean wasSearchContentViewSeen, boolean wasActivatedByTap) {
        if (wasActivatedByTap && ContextualSearchFieldTrial.isScreenTopCollectionEnabled()) {
            ContextualSearchUma.logScreenTopTapLocation(
                    wasSearchContentViewSeen, wasActivatedByTap, mYDp);
        }
    }
}

==> chromium-55.0.2859.0.tar.xz: chromium-55.0.2859.0/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/NearTopTapSuppression.java <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.contextualsearch;

/**
 * Heuristic for Tap suppression near the top of the content view area.
 * Handles logging of results seen and the condition state.
 */
public class NearTopTapSuppression extends ContextualSearchHeuristic {
    private final int mExperiementThresholdDps;
    private final boolean mIsConditionSatisfied;
    private final int mYDp;

    /**
     * Constructs a Tap suppression heuristic that handles a Tap after a recent scroll.
     * This logs activation data that includes whether it activated for a threshold specified
     * by an experiment. This also logs Results-seen data to profile when results are seen relative
     * to a recent scroll.
     * @param selectionController The {@link ContextualSearchSelectionController}.
     */
    NearTopTapSuppression(ContextualSearchSelectionController selectionController, int y) {
        mExperiementThresholdDps = ContextualSearchFieldTrial.getScreenTopSuppressionDps();
        mYDp = (int) (y * selectionController.getPxToDp());
        mIsConditionSatisfied = mYDp < mExperiementThresholdDps;
    }

    @Override
    protected boolean isConditionSatisfied() {
        return mIsConditionSatisfied;
    }

    @Override
    protected void logConditionState() {
        if (mExperiementThresholdDps > 0) {
            ContextualSearchUma.logScreenTopTapSuppression(mIsConditionSatisfied);
        }
    }

    @Override
    protected void logResultsSeen(boolean wasSearchContentViewSeen, boolean wasActivatedByTap) {
        if (wasActivatedByTap) {
            ContextualSearchUma.logScreenTopTapLocation(
                    wasSearchContentViewSeen, wasActivatedByTap, mYDp);
        }
    }

    @Override
    protected boolean isConditionSatisfiedForAggregateLogging() {
        // TODO(twellington): Define a default value to use when determining if the condition is
        // satisfied for logging.
        return false;
    }
}
